@@ -3,6 +3,9 @@
 # scrub -std=... flag which conflicts with builds
 export CXXFLAGS=$(echo ${CXXFLAGS:-} | sed -E 's@\-std=[^ ]*@@g')
 
+# *add* C std
+export CFLAGS="$CFLAGS -std=c99"
+
 # Increase CPUs for multiarch builds
 if [ "$(uname -m)" = "armv8" ] || [ "$(uname -m)" = "ppc64le" ]; then
     echo "Using $(grep -c ^processor /proc/cpuinfo) CPUs"
@@ -20,7 +23,15 @@ echo "sysroot: ${CONDA_BUILD_SYSROOT:-unset}"
 
 # The without snapshot comes from the error in
 # https://github.com/nodejs/node/issues/4212.
-./configure --prefix=$PREFIX --without-snapshot
+./configure \
+    --prefix=$PREFIX \
+    --without-snapshot \
+    --without-node-snapshot \
+    --shared-libuv \
+    --shared-openssl \
+    --shared-zlib \
+    --with-intl=system-icu
+
 make -j${CPU_COUNT}
 make install > /dev/null
 
